accent property
Spacing Unicode character for the accent, or a shape name for stretchy accents without one.
Implementation
final String accent;
Spacing Unicode character for the accent, or a shape name for stretchy accents without one.
final String accent;