GlyphVariant class final

One size variant of a glyph.

Constructors

GlyphVariant(int glyph, int advance)
Creates a variant.
const

Properties

advance → int
Its full advance in the stretch direction, font units.
final
glyph → int
Variant glyph id.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited