LetMacro class final

A control sequence made equal to a non-macro token with \let, e.g. \let\foo\frac. Expanding it yields token, marked unexpandable.

Inheritance

Constructors

LetMacro(Token token)
Creates an alias for token.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → Token
The token this name now means.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited