expandOnce method
Expands the next token once if it is a macro. Returns false otherwise.
Implementation
bool expandOnce() {
final t = peekRaw();
if (!_expandable(t)) return false;
_expandOnce();
return true;
}
Expands the next token once if it is a macro. Returns false otherwise.
bool expandOnce() {
final t = peekRaw();
if (!_expandable(t)) return false;
_expandOnce();
return true;
}