popRaw method
Removes and returns the next token without expanding it.
Implementation
Token popRaw() {
final t = peekRaw();
if (!t.isEof) _stack.removeLast();
if (t.isEof) hitEndOfInput = true;
return t;
}
Removes and returns the next token without expanding it.
Token popRaw() {
final t = peekRaw();
if (!t.isEof) _stack.removeLast();
if (t.isEof) hitEndOfInput = true;
return t;
}