MathConstants class final

The OpenType MATH table constants, in font units.

Names follow the OpenType specification. The two percentages are plain numbers (e.g. 70 for 70%).

Properties

all → Map<String, int>
All constants.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String name) → int
Value of the constant name (see names).

Constants

names → const List<String>
Names of the constants, in table order.