MathKern class final

Math kerning for one corner of a glyph: kern values between heights.

Constructors

MathKern(List<int> heights, List<int> kerns)
Creates a kern table.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
heights → List<int>
Correction heights, ascending (font units).
final
kerns → List<int>
Kern values; one more than heights.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

at(double height) → int
The kern to use at height.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited