MathKernInfo class final

The four math kern corners of a glyph.

Constructors

MathKernInfo({MathKern? topRight, MathKern? topLeft, MathKern? bottomRight, MathKern? bottomLeft})
Creates kern info.
const

Properties

bottomLeft → MathKern?
Bottom-left corner (pre-subscripts).
final
bottomRight → MathKern?
Bottom-right corner (subscripts).
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topLeft → MathKern?
Top-left corner (pre-superscripts).
final
topRight → MathKern?
Top-right corner (superscripts).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited