StretchInfo class final

How a glyph stretches, in em.

Constructors

StretchInfo(List<(int, double)> variants, List<StretchPart> parts, double italicsCorrection)
Creates stretch info.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
italicsCorrection → double
Italics correction of the assembly.
final
parts → List<StretchPart>
Assembly parts (bottom→top / left→right); empty if none.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variants → List<(int, double)>
Ready-made variants: (glyph, advance in the stretch direction).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited