SymbolInfo class final

What a math-mode symbol command means.

Constructors

SymbolInfo(String text, AtomType atom, {bool variant = false})
Creates a symbol entry.
const

Properties

atom → AtomType
TeX atom class.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Unicode text.
final
variant → bool
Prefer the font's variant glyph.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited