span property
Where the token came from. Tokens produced by expanding a macro carry the span of the macro call.
Implementation
final SourceSpan span;
Where the token came from. Tokens produced by expanding a macro carry the span of the macro call.
final SourceSpan span;