TokenKind enum

What kind of Token this is.

Inheritance
Available extensions

Values

controlWord → const TokenKind

\ followed by letters (and @), e.g. \frac. Text includes the backslash. A lone \ at the end of input is also a control word with text \.

controlSymbol → const TokenKind

\ followed by one non-letter character, e.g. \, or \\.

character → const TokenKind

One grapheme cluster that is not a control sequence or whitespace.

space → const TokenKind

One or more whitespace characters, collapsed.

verb → const TokenKind

A complete \verb or \verb* form; text is the whole form.

eof → const TokenKind

End of input.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TokenKind>
A constant List of the values in this enum, in order of their declaration.