FontAxis class final

A design axis of a variable font (fvar): weight (wght), width (wdth), optical size (opsz)…, in the font's own user units.

Constructors

FontAxis(String tag, double minValue, double defaultValue, double maxValue, {String? name, bool hidden = false})
Creates an axis.
const

Properties

defaultValue → double
Value of the default instance.
final
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
Whether the font asks for the axis to be hidden from users.
final
maxValue → double
Largest value.
final
minValue → double
Smallest value.
final
name → String?
Name for people (from the name table), if any.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String
Four-character tag.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited