GlyphPath class final

A glyph outline.

Constructors

GlyphPath(List<PathCommand> commands)
Creates a path from commands.

Properties

bounds → GlyphBounds
Tight bounds of the ink, including curve extrema.
no setter
commands → List<PathCommand>
The commands, in order.
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether there is no ink.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

mirrored(double width) → GlyphPath
This outline reflected left-to-right within an advance of width font units (x' = width - x).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toSvgPathData({double scale = 1, double dx = 0, double dy = 0}) → String
SVG path data (y flipped to screen coordinates, scaled by scale).

Operators

operator ==(Object other) → bool
The equality operator.
inherited