AccentInfo class final
An accent command.
Constructors
Properties
- accent → String
-
Spacing Unicode character for the accent, or a shape name for
stretchy accents without one.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- math → bool
-
Allowed in math mode.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stretchy → bool
-
Stretches to the base's width.
final
- text → bool
-
Allowed in text mode.
final
- under → bool
-
Placed below the base.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited