FunctionMacro class final
A macro implemented in Dart. It may read further tokens through the MacroExpander and returns the tokens to expand to (possibly none).
- Inheritance
-
- Object
- MacroDefinition
- FunctionMacro
Constructors
-
FunctionMacro(List<
Token> expand(MacroExpander expander, Token call)) -
Creates a function macro.
const
Properties
-
expand
→ List<
Token> Function(MacroExpander expander, Token call) -
Performs the expansion.
callis the macro's own token.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited