GlyphPart class final
A piece of an extensible glyph assembly.
Constructors
Properties
- endConnector → int
-
Length of the connector at the end (top/right).
final
- fullAdvance → int
-
Full advance of the part.
final
- glyph → int
-
Part glyph id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExtender → bool
-
Whether the part may be repeated.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startConnector → int
-
Length of the connector at the start (bottom/left).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited