Lexer constructor

Lexer(
  1. String input, {
  2. int spanOffset = 0,
})

Creates a lexer over input. spanOffset is added to every span, for lexing macro bodies that do not come from the user's source.

Implementation

Lexer(this.input, {this.spanOffset = 0});