MacroArgument class final
A macro argument read by MacroExpander.
Constructors
-
MacroArgument(List<
Token> tokens, int end, {bool incomplete = false}) -
Creates an argument.
const
Properties
- end → int
-
Source offset just after the argument.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- incomplete → bool
-
Whether the end of input cut the argument off.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tokens
→ List<
Token> -
The argument's tokens (braces removed).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited