overBudget property
Returns true when the parse has run out of time; checked every 64 expansions so a runaway recursive macro stops within the budget.
Implementation
final bool Function()? overBudget;
Returns true when the parse has run out of time; checked every 64 expansions so a runaway recursive macro stops within the budget.
final bool Function()? overBudget;