SiOptions class final

Options given in […] that change the output.

Constructors

SiOptions({PerMode perMode = PerMode.power})
Creates options.
const
SiOptions.parse(String? text)
Reads key=value pairs; unknown keys are ignored.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
perMode → PerMode
How \per is written.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited