StretchPart class final
A size variant or assembly part in em.
Constructors
Properties
- endConnector → double
-
End connector length.
final
- fullAdvance → double
-
Full advance.
final
- glyph → int
-
Glyph id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExtender → bool
-
Repeatable.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startConnector → double
-
Start connector length.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited