AtomType enum
TeX's math atom classes (TeXbook ch. 17), which decide spacing.
Values
- ord → const AtomType
-
Ordinary: letters, digits, most symbols.
- op → const AtomType
-
Large operator:
\sum,\int,\lim. - bin → const AtomType
-
Binary operation:
+,\times. - rel → const AtomType
-
Relation:
=,<,\to. - open → const AtomType
-
Opening delimiter:
(,\langle. - close → const AtomType
-
Closing delimiter:
),\rangle. - punct → const AtomType
-
Punctuation:
,,;. - inner → const AtomType
-
Inner: fractions and
\left…\rightgroups.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited